Struct strava_data::models::DetailedActivity[][src]

pub struct DetailedActivity {
Show 42 fields pub id: Option<i64>, pub external_id: Option<String>, pub upload_id: Option<i64>, pub athlete: Option<MetaAthlete>, pub name: Option<String>, pub distance: Option<f32>, pub moving_time: Option<i32>, pub elapsed_time: Option<i32>, pub total_elevation_gain: Option<f32>, pub elev_high: Option<f32>, pub elev_low: Option<f32>, pub activity_type: Option<ActivityType>, pub start_date: Option<String>, pub start_date_local: Option<String>, pub timezone: Option<String>, pub utc_offset: Option<f32>, pub achievement_count: Option<i32>, pub kudos_count: Option<i32>, pub comment_count: Option<i32>, pub athlete_count: Option<i32>, pub photo_count: Option<i32>, pub total_photo_count: Option<i32>, pub map: Option<PolylineMap>, pub trainer: Option<bool>, pub commute: Option<bool>, pub manual: Option<bool>, pub private: Option<bool>, pub flagged: Option<bool>, pub workout_type: Option<i32>, pub upload_id_str: Option<String>, pub average_speed: Option<f32>, pub max_speed: Option<f32>, pub has_kudoed: Option<bool>, pub gear_id: Option<String>, pub kilojoules: Option<f32>, pub average_watts: Option<f32>, pub device_watts: Option<bool>, pub max_watts: Option<i32>, pub description: Option<String>, pub calories: Option<f32>, pub device_name: Option<String>, pub embed_token: Option<String>, // some fields omitted
}

Fields

id: Option<i64>

The unique identifier of the activity

external_id: Option<String>

The identifier provided at upload time

upload_id: Option<i64>

The identifier of the upload that resulted in this activity

athlete: Option<MetaAthlete>name: Option<String>

The name of the activity

distance: Option<f32>

The activity’s distance, in meters

moving_time: Option<i32>

The activity’s moving time, in seconds

elapsed_time: Option<i32>

The activity’s elapsed time, in seconds

total_elevation_gain: Option<f32>

The activity’s total elevation gain.

elev_high: Option<f32>

The activity’s highest elevation, in meters

elev_low: Option<f32>

The activity’s lowest elevation, in meters

activity_type: Option<ActivityType>start_date: Option<String>

The time at which the activity was started.

start_date_local: Option<String>

The time at which the activity was started in the local timezone.

timezone: Option<String>

The timezone of the activity

utc_offset: Option<f32>

The UTC offset of the local timezone

achievement_count: Option<i32>

The number of achievements gained during this activity

kudos_count: Option<i32>

The number of kudos given for this activity

comment_count: Option<i32>

The number of comments for this activity

athlete_count: Option<i32>

The number of athletes for taking part in a group activity

photo_count: Option<i32>

The number of Instagram photos for this activity

total_photo_count: Option<i32>

The number of Instagram and Strava photos for this activity

map: Option<PolylineMap>trainer: Option<bool>

Whether this activity was recorded on a training machine

commute: Option<bool>

Whether this activity is a commute

manual: Option<bool>

Whether this activity was created manually

private: Option<bool>

Whether this activity is private

flagged: Option<bool>

Whether this activity is flagged

workout_type: Option<i32>

The activity’s workout type

upload_id_str: Option<String>

The unique identifier of the upload in string format

average_speed: Option<f32>

The activity’s average speed, in meters per second

max_speed: Option<f32>

The activity’s max speed, in meters per second

has_kudoed: Option<bool>

Whether the logged-in athlete has kudoed this activity

gear_id: Option<String>

The id of the gear for the activity

kilojoules: Option<f32>

The total work done in kilojoules during this activity. Rides only

average_watts: Option<f32>

Average power output in watts during this activity. Rides only

device_watts: Option<bool>

Whether the watts are from a power meter, false if estimated

max_watts: Option<i32>

Rides with power meter data only

description: Option<String>

The description of the activity

calories: Option<f32>

The number of kilocalories consumed during this activity

device_name: Option<String>

The name of the device used to record the activity

embed_token: Option<String>

The token used to embed a Strava activity